yt.visualization.volume_rendering.camera.Camera.show — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.camera.Camera.show

`Camera.` `show`(clip_ratio=None)

  This will take a snapshot and display the resultant image in the IPython notebook.

  If yt is being run from within an IPython session, and it is able to determine this, this function will snapshot and send the resultant image to the IPython notebook for display.

  If yt can’t determine if it’s inside an IPython session, it will raise YTNotInsideNotebook.

  Parameters: | clip_ratio : float, optional If supplied, the ‘max_val’ argument to write_bitmap will be handed clip_ratio * image.std()

  Examples

      >>> cam.show()